@@ -13,6 +13,17 @@
 #
 ###############################################################################
 
+@doc raw"""
+    complex_field()
+
+Return the field of complex numbers modelled via complex balls.
+
+See `precision` and `set_precision!` on how to control the precision.
+"""
+function complex_field()
+  return ComplexField()
+end
+
 elem_type(::Type{ComplexField}) = ComplexFieldElem
 
 parent_type(::Type{ComplexFieldElem}) = ComplexField
@@ -21,7 +32,7 @@ base_ring_type(::Type{ComplexField}) = typeof(Union{})
 
 base_ring(R::ComplexField) = Union{}
 
-parent(x::ComplexFieldElem) = ComplexField()
+parent(x::ComplexFieldElem) = complex_field()
 
 is_domain_type(::Type{ComplexFieldElem}) = true
 
@@ -34,7 +45,7 @@ one(r::ComplexField) = one!(ComplexFieldElem())
 @doc raw"""
     onei(r::ComplexField)
 
-Return exact one times $i$ in the given Arb complex field.
+Return exact one times $i$ in the given complex field.
 """
 function onei(r::ComplexField)
   z = ComplexFieldElem()
@@ -184,8 +195,6 @@ end
 #
 ################################################################################
 
-# AcbFieldElem - AcbFieldElem
-
 for (s,f) in ((:+,"acb_add"), (:*,"acb_mul"), (://, "acb_div"), (:-,"acb_sub"), (:^,"acb_pow"))
   @eval begin
     function ($s)(x::ComplexFieldElem, y::ComplexFieldElem, prec::Int = precision(Balls))
@@ -449,7 +458,7 @@ contains(x::ComplexFieldElem, y::Integer) = contains(x, ZZRingElem(y))
 Returns `true` if the box $x$ contains the given rational value, otherwise
 return `false`.
 """
-contains(x::ComplexFieldElem, y::Rational{T}) where {T <: Integer} = contains(x, ZZRingElem(y))
+contains(x::ComplexFieldElem, y::Rational{T}) where {T <: Integer} = contains(x, QQFieldElem(y))
 
 @doc raw"""
     contains_zero(x::ComplexFieldElem)
@@ -1178,7 +1187,7 @@ end
 @doc raw"""
     rising_factorial(x::ComplexFieldElem, n::Int)
 
-Return the rising factorial $x(x + 1)\ldots (x + n - 1)$ as an Acb.
+Return the rising factorial $x(x + 1)\ldots (x + n - 1)$.
 """
 function rising_factorial(x::ComplexFieldElem, n::Int)
   n < 0 && throw(DomainError(n, "Argument must be non-negative"))
@@ -1752,7 +1761,7 @@ for S in (Real, ZZRingElem, QQFieldElem, RealFieldElem, AbstractString)
     if S != T || S == Real
       @eval begin
         function (r::ComplexField)(x::$(S), y::$(T); precision::Int = precision(Balls))
-          z = ComplexFieldElem(RealField()(x), RealField()(y), precision)
+          z = ComplexFieldElem(real_field()(x), real_field()(y), precision)
           return z
         end
       end
