@@ -138,11 +138,14 @@ end
 
 ################################################################################
 #
-#   Hashing
+#   Low-level direct access
 #
 ################################################################################
 
-# Similar to hash for BigInt found in julia/base
+@inline function __fmpz_is_small(a::Int)
+  return (unsigned(a) >> (Sys.WORD_SIZE - 2) != 1)
+end
+
 @inline function _fmpz_is_small(a::ZZRingElemOrPtr)
   return __fmpz_is_small(data(a))
 end
@@ -158,6 +161,12 @@ end
   return _fmpz_is_small(a) ? 1 : GC.@preserve a _as_bigint(a).size
 end
 
+################################################################################
+#
+#   Hashing
+#
+################################################################################
+
 function hash_integer(a::ZZRingElem, h::UInt)
   return GC.@preserve a _hash_integer(data(a), h)
 end
@@ -167,10 +176,6 @@ function hash(a::ZZRingElem, h::UInt)
   return hash_integer(a, h)
 end
 
-@inline function __fmpz_is_small(a::Int)
-  return (unsigned(a) >> (Sys.WORD_SIZE - 2) != 1)
-end
-
 function _hash_integer(a::Int, h::UInt)
   __fmpz_is_small(a) && return Base.hash_integer(a, h)
   # view it as a BigInt
@@ -232,22 +237,29 @@ is_positive(n::ZZRingElemOrPtr) = sign(Int, n) > 0
 
 Return `true` if $a$ fits into an `Int`, otherwise return `false`.
 """
-fits(::Type{Int}, a::ZZRingElem) = @ccall libflint.fmpz_fits_si(a::Ref{ZZRingElem})::Bool
+function fits(::Type{Int}, a::ZZRingElem)
+  _fmpz_is_small(a) && return true
+  n = _fmpz_size(a)
+  n == 1 && return rem(a, UInt) <= typemax(Int)
+  n == -1 && return rem(a, UInt) >= reinterpret(UInt,typemin(Int))
+  return false
+end
 
 @doc raw"""
     fits(::Type{UInt}, a::ZZRingElem)
 
 Return `true` if $a$ fits into a `UInt`, otherwise return `false`.
 """
-@inline function fits(::Type{UInt}, a::ZZRingElem)
-  a < 0 && return false
-  return @ccall libflint.fmpz_abs_fits_ui(a::Ref{ZZRingElem})::Bool
+function fits(::Type{UInt}, a::ZZRingElem)
+  return !is_negative(a) && size(a) == 1
 end
 
-if Culong !== UInt
-  function fits(::Type{Culong}, a::ZZRingElem)
-    return 0 <= a && a <= UInt(typemax(Culong))
-  end
+function fits(::Type{T}, a::ZZRingElem) where {T <: Union{Int32,Int16,Int8,UInt32,UInt16,UInt8}}
+  return _fmpz_is_small(a) && typemin(T) <= data(a) <= typemax(T)
+end
+
+function fits(::Type{T}, a::ZZRingElem) where {T <: Integer}
+  return typemin(T) <= a <= typemax(T)
 end
 
 @doc raw"""
@@ -490,7 +502,7 @@ function is_divisible_by(x::Integer, y::ZZRingElem)
   return is_divisible_by(ZZRingElem(x), y)
 end
 
-function rem(x::ZZRingElemOrPtr, ::Type{UInt64})
+function rem(x::ZZRingElemOrPtr, ::Type{UInt})
   return _fmpz_is_small(x) ? (data(x) % UInt) : GC.@preserve x (_as_bigint(x) % UInt)
 end
 
@@ -821,7 +833,7 @@ end
 ###############################################################################
 
 function cmp(x::ZZRingElemOrPtr, y::ZZRingElemOrPtr)
-  Int(@ccall libflint.fmpz_cmp(x::Ref{ZZRingElem}, y::Ref{ZZRingElem})::Cint)
+  @ccall libflint.fmpz_cmp(x::Ref{ZZRingElem}, y::Ref{ZZRingElem})::Cint
 end
 
 ==(x::ZZRingElem, y::ZZRingElem) = cmp(x,y) == 0
@@ -836,9 +848,9 @@ end
 
 isless(x::ZZRingElem, y::ZZRingElem) = x < y
 
-isless(x::ZZRingElem, y::Integer) = x < ZZRingElem(y)
+isless(x::ZZRingElem, y::Integer) = x < flintify(y)
 
-isless(x::Integer, y::ZZRingElem) = ZZRingElem(x) < y
+isless(x::Integer, y::ZZRingElem) = flintify(x) < y
 
 function Base.isapprox(x::ZZRingElem, y::ZZRingElem;
                        atol::Real=0, rtol::Real=0,
@@ -857,37 +869,28 @@ end
 ###############################################################################
 
 function cmp(x::ZZRingElemOrPtr, y::Int)
+  _fmpz_is_small(x) && return cmp(data(x), y)
   Int(@ccall libflint.fmpz_cmp_si(x::Ref{ZZRingElem}, y::Int)::Cint)
 end
 
-==(x::ZZRingElem, y::Int) = cmp(x,y) == 0
-
-<=(x::ZZRingElem, y::Int) = cmp(x,y) <= 0
-
-<(x::ZZRingElem, y::Int) = cmp(x,y) < 0
-
-==(x::Int, y::ZZRingElem) = cmp(y,x) == 0
-
-<=(x::Int, y::ZZRingElem) = cmp(y,x) >= 0
-
-<(x::Int, y::ZZRingElem) = cmp(y,x) > 0
-
 function cmp(x::ZZRingElemOrPtr, y::UInt)
+  _fmpz_is_small(x) && return cmp(data(x), y)
   Int(@ccall libflint.fmpz_cmp_ui(x::Ref{ZZRingElem}, y::UInt)::Cint)
 end
 
-==(x::ZZRingElem, y::UInt) = cmp(x,y) == 0
+cmp(x::ZZRingElemOrPtr, y::Integer) = cmp(x, flintify(y))
 
-<=(x::ZZRingElem, y::UInt) = cmp(x,y) <= 0
-
-<(x::ZZRingElem, y::UInt) = cmp(x,y) < 0
-
-==(x::UInt, y::ZZRingElem) = cmp(y,x) == 0
-
-<=(x::UInt, y::ZZRingElem) = cmp(y,x) >= 0
-
-<(x::UInt, y::ZZRingElem) = cmp(y,x) > 0
+for T in (Int, UInt, Integer)
+  @eval begin
+    ==(x::ZZRingElem, y::$T) = cmp(x,y) == 0
+    <=(x::ZZRingElem, y::$T) = cmp(x,y) <= 0
+    <(x::ZZRingElem, y::$T) = cmp(x,y) < 0
 
+    ==(x::$T, y::ZZRingElem) = cmp(y,x) == 0
+    <=(x::$T, y::ZZRingElem) = cmp(y,x) >= 0
+    <(x::$T, y::ZZRingElem) = cmp(y,x) > 0
+  end
+end
 
 ==(x::ZZRingElem, y::Rational) = isinteger(y) && x == numerator(y)
 
@@ -957,7 +960,7 @@ end
 #
 ###############################################################################
 
-function mod!(r::ZZRingElem, x::ZZRingElem, y::ZZRingElem)
+function mod!(r::ZZRingElemOrPtr, x::ZZRingElemOrPtr, y::ZZRingElemOrPtr)
   @ccall libflint.fmpz_fdiv_r(r::Ref{ZZRingElem}, x::Ref{ZZRingElem}, y::Ref{ZZRingElem})::Nothing
   return r
 end
@@ -2968,17 +2971,19 @@ function (::Type{BigInt})(a::ZZRingElem)
 end
 
 function (::Type{Int})(a::ZZRingElem)
-  (a > typemax(Int) || a < typemin(Int)) && throw(InexactError(:convert, Int, a))
+  _fmpz_is_small(a) && return data(a)
+  fits(Int, a) || throw(InexactError(:convert, Int, a))
   return @ccall libflint.fmpz_get_si(a::Ref{ZZRingElem})::Int
 end
 
 function (::Type{UInt})(a::ZZRingElem)
-  (a > typemax(UInt) || a < 0) && throw(InexactError(:convert, UInt, a))
-  return @ccall libflint.fmpz_get_ui(a::Ref{ZZRingElem})::UInt
+  fits(UInt, a) || throw(InexactError(:convert, UInt, a))
+  return rem(a, UInt)
 end
 
 if Culong !== UInt
   function (::Type{Culong})(a::ZZRingElem)
+    _fmpz_is_small(a) && return Culong(data(a))
     fits(Culong, a) || throw(InexactError(:convert, Culong, a))
     return (@ccall libflint.fmpz_get_ui(a::Ref{ZZRingElem})::UInt) % Culong
   end
@@ -2988,8 +2993,10 @@ end
 
 (::Type{T})(a::ZZRingElem) where T <: Union{UInt8, UInt16, UInt32} = T(UInt(a))
 
-(::Type{Int128})(a::ZZRingElem) = Int128(BigInt(a))
-(::Type{UInt128})(a::ZZRingElem) = UInt128(BigInt(a))
+function (::Type{T})(a::ZZRingElem) where T <: Union{Int128, UInt128}
+  _fmpz_is_small(a) && return T(data(a))
+  T(BigInt(a))
+end
 
 Base.Integer(a::ZZRingElem) = BigInt(a)
 
