@@ -632,7 +632,7 @@ end
 end
 
 @testset "QQFieldElem.simplest_between" begin
-  @test @inferred simplest_between(QQFieldElem(-2//2), QQFieldElem(1)) == -1
+  @test (@inferred simplest_between(QQFieldElem(-2//2), QQFieldElem(1))) == -1
   @test simplest_between(QQFieldElem(1//10), QQFieldElem(3//10)) == 1//4
   @test simplest_between(QQFieldElem(11//10), QQFieldElem(21//10)) == 2
 end
@@ -688,11 +688,357 @@ end
 
 @testset "QQFieldElem.is_perfect_power_with_data" begin
   for T in [Rational{Int}, Rational{BigInt}, QQFieldElem]
-    @test @inferred is_perfect_power_with_data(T(5//9)) == (1, 5//9)
-    @test @inferred is_perfect_power_with_data(T(4//9)) == (2, 2//3)
+    @test (@inferred is_perfect_power_with_data(T(5//9))) == (1, 5//9)
+    @test (@inferred is_perfect_power_with_data(T(4//9))) == (2, 2//3)
   end
 
   @test is_power(QQ(2), 2)[1] == false
   @test is_power(QQ(1//2), 2)[1] == false
   @test is_power(QQ(4//9), 2) == (true, 2//3)
 end
+
+@testset "Rings.QQ.constructors" begin
+   @test QQ === fraction_field(ZZ)
+
+   @test QQ(1, 2) isa QQFieldElem
+   @test QQ(1, ZZ(2)) isa QQFieldElem
+   @test QQ(ZZ(1), 2) isa QQFieldElem
+   @test QQ(ZZ(1), ZZ(2)) isa QQFieldElem
+   @test QQ(2) isa QQFieldElem
+   @test QQ(ZZ(2)) isa QQFieldElem
+   @test QQ() isa QQFieldElem
+
+   @test 1//ZZ(2) isa QQFieldElem
+   @test ZZ(1)//2 isa QQFieldElem
+   @test ZZ(1)//ZZ(2) isa QQFieldElem
+
+   @test zero(QQ) isa QQFieldElem
+   @test one(QQ) isa QQFieldElem
+
+   @test QQ(1, -2) == -1//2
+   @test QQ(-1, 2) == -1//2
+   @test QQ(-1, -2) == 1//2
+   @test QQ(ZZ(1), -2) == -1//2
+   @test QQ(ZZ(-1), 2) == -1//2
+   @test QQ(ZZ(-1), -2) == 1//2
+   @test QQ(1, ZZ(-2)) == -1//2
+   @test QQ(-1, ZZ(2)) == -1//2
+   @test QQ(-1, ZZ(-2)) == 1//2
+   @test QQ(ZZ(1), ZZ(-2)) == -1//2
+   @test QQ(ZZ(-1), ZZ(2)) == -1//2
+   @test QQ(ZZ(-1), ZZ(-2)) == 1//2
+
+   @test QQ(0, 2) == 0
+   @test QQ(0, -1) == 0
+
+   @test QQ(3) == 3
+   @test QQ(0) == 0
+
+   @test QQ() == 0
+
+   @test QQ(2//3) == 2//3
+   @test QQ(-2//3) == -2//3
+   @test QQ(0//3) == 0
+
+   @test QQ(BigInt(2)//3) == 2//3
+
+   @test ZZ(1)//(-2) == -1//2
+   @test ZZ(-1)//2 == -1//2
+   @test ZZ(-1)//-2 == 1//2
+   @test 1//ZZ(-2) == -1//2
+   @test -1//ZZ(2) == -1//2
+   @test -1//ZZ(-2) == 1//2
+   @test ZZ(1)//ZZ(-2) == -1//2
+   @test ZZ(-1)//ZZ(2) == -1//2
+   @test ZZ(-1)//ZZ(-2) == 1//2
+
+   @test 0//ZZ(2) == 0
+   @test 0//ZZ(-1) == 0
+
+   @test QQ(1, typemax(Int)) == 1//typemax(Int)
+   @test QQ(typemax(Int), 1) == typemax(Int)
+   @test QQ(1, typemin(Int)) == 1//BigInt(typemin(Int)) # must use BigInt
+   @test QQ(typemin(Int), 1) == typemin(Int)
+   @test QQ(typemin(Int), -1) == -BigInt(typemin(Int)) # must use BigInt
+   @test QQ(typemax(Int), -1) == -BigInt(typemax(Int)) # must use BigInt
+   @test QQ(-1, typemin(Int)) == 1//-BigInt(typemin(Int)) # must use BigInt
+   @test QQ(-1, typemax(Int)) == -1//typemax(Int)
+
+   @test QQ(2//typemin(Int)) == 1//(div(typemin(Int), 2))
+
+   @test_throws DivideError ZZ(2)//0
+   @test_throws DivideError 2//ZZ(0)
+   @test_throws DivideError ZZ(2)//ZZ(0)
+   @test_throws DivideError ZZ(0)//0
+   @test_throws DivideError 0//ZZ(0)
+   @test_throws DivideError ZZ(0)//ZZ(0)
+
+   @test_throws DivideError QQ(2, 0)
+   @test_throws DivideError QQ(ZZ(2), 0)
+   @test_throws DivideError QQ(2, ZZ(0))
+   @test_throws DivideError QQ(ZZ(2), ZZ(0))
+   @test_throws DivideError QQ(0, 0)
+   @test_throws DivideError QQ(ZZ(0), 0)
+   @test_throws DivideError QQ(0, ZZ(0))
+   @test_throws DivideError QQ(ZZ(0), ZZ(0))
+end
+
+@testset "Rings.QQ.properties" begin
+   @test iszero(QQ())
+   @test !iszero(QQ(-1, 3))
+   @test isone(one(QQ))
+   @test !isone(-one(QQ))
+   @test is_unit(QQ(2, 3))
+   @test is_unit(QQ(-1, 3))
+   @test !is_unit(zero(QQ))
+
+   @test numerator(QQ(2, 1)) == 2
+   @test denominator(QQ(2, 1)) == 1
+
+   @test numerator(QQ(6, 3)) == 2
+   @test denominator(QQ(6, 3)) == 1
+
+   @test numerator(QQ(-2, 3)) == -2
+   @test denominator(QQ(-2, 3)) == 3
+
+   @test numerator(QQ(2, -3)) == -2
+   @test denominator(QQ(2, -3)) == 3
+
+   @test numerator(QQ(-2, -3)) == 2
+   @test denominator(QQ(-2, -3)) == 3
+
+   @test numerator(QQ()) == 0
+   @test denominator(QQ()) == 1
+
+   @test numerator(QQ(-2, 3)) isa ZZRingElem
+   @test denominator(QQ(-2, 3)) isa ZZRingElem
+
+   @test numerator(QQ()) isa ZZRingElem
+   @test denominator(QQ()) isa ZZRingElem
+
+   @test numerator(QQ(1)) isa ZZRingElem
+   @test denominator(QQ(1)) isa ZZRingElem
+
+   @test sign(QQ(-2, 3)) == -1
+   @test sign(QQ()) == 0
+   @test sign(QQ(2, 3)) == 1
+   @test sign(QQ(1)) == 1
+   @test sign(QQ(-1)) == -1
+   @test sign(QQ(-2)) == -1
+   @test sign(QQ(0)) == 0
+
+   @test sign(QQ(-2, 3)) isa QQFieldElem
+   @test sign(QQ()) isa QQFieldElem
+   @test sign(QQ(1)) isa QQFieldElem
+   @test sign(QQ(-1)) isa QQFieldElem
+
+   @test abs(QQ(-2, 3)) == 2//3
+   @test abs(QQ()) == 0
+   @test abs(QQ(2)) == 2
+
+   @test abs(QQ(-2, 3)) isa QQFieldElem
+   @test abs(QQ()) isa QQFieldElem
+   @test abs(QQ(2)) isa QQFieldElem
+
+   @test height(QQ(-2, 3)) isa ZZRingElem
+   @test height(QQ()) isa ZZRingElem
+   @test height(QQ(2)) isa ZZRingElem
+
+   @test height(QQ(-3, 2)) == 3
+   @test height(QQ(-2, 3)) == 3
+   @test height(QQ(7, 5)) == 7
+   @test height(QQ(5, 7)) == 7
+   @test height(QQ()) == 1
+   @test height(QQ(-1)) == 1
+   @test height(QQ(2)) == 2
+
+   @test floor(QQ(-2, 3)) isa QQFieldElem
+   @test floor(QQ(7, 5)) isa QQFieldElem
+   @test floor(QQ(2)) isa QQFieldElem
+   @test floor(QQ()) isa QQFieldElem
+
+   @test ceil(QQ(-2, 3)) isa QQFieldElem
+   @test ceil(QQ(7, 5)) isa QQFieldElem
+   @test ceil(QQ(2)) isa QQFieldElem
+   @test ceil(QQ()) isa QQFieldElem
+
+   @test floor(QQ(-1, 2)) == -1
+   @test floor(QQ(1, 2)) == 0
+   @test floor(QQ(1)) == 1
+   @test floor(QQ(0)) == 0
+   @test floor(QQ(-1)) == -1
+
+   @test floor(QQ(-1, 2)) == -1
+   @test floor(QQ(1, 2)) == 0
+   @test floor(QQ(1)) == 1
+   @test floor(QQ(0)) == 0
+   @test floor(QQ(-1)) == -1
+end
+
+@testset "Rings.QQ.arithmetic" begin
+   @test QQ(2, 3) + 1 isa QQFieldElem
+   @test QQ(2, 3) - 1 isa QQFieldElem
+   @test QQ(2, 3)*2 isa QQFieldElem
+   @test QQ(1, 2) + 12345678901234567890 isa QQFieldElem
+   @test QQ(1, 2) + 1234567890123456789012345678901234567890 isa QQFieldElem
+   @test QQ(1, 2) - 12345678901234567890 isa QQFieldElem
+   @test QQ(1, 2) - 1234567890123456789012345678901234567890 isa QQFieldElem
+   @test QQ(1, 2)*12345678901234567890 isa QQFieldElem
+   @test QQ(1, 2)*1234567890123456789012345678901234567890 isa QQFieldElem
+
+   @test 1 + QQ(2, 3) isa QQFieldElem
+   @test 1 - QQ(2, 3) isa QQFieldElem
+   @test 2*QQ(2, 3) isa QQFieldElem
+   @test 12345678901234567890 + QQ(1, 2) isa QQFieldElem
+   @test 1234567890123456789012345678901234567890 + QQ(1, 2) isa QQFieldElem
+   @test 12345678901234567890 - QQ(1, 2) isa QQFieldElem
+   @test 1234567890123456789012345678901234567890 - QQ(1, 2) isa QQFieldElem
+   @test 12345678901234567890*QQ(1, 2) isa QQFieldElem
+   @test 1234567890123456789012345678901234567890*QQ(1, 2) isa QQFieldElem
+
+   @test QQ(2, 3) + 2//5 isa QQFieldElem
+   @test QQ(2, 3) - 2//5 isa QQFieldElem
+   @test QQ(2, 3)*(2//5) isa QQFieldElem
+   @test QQ(2, 3) + 12345678901234567890//5 isa QQFieldElem
+   @test QQ(2, 3) - 12345678901234567890//5 isa QQFieldElem
+   @test QQ(2, 3)*(12345678901234567890//5) isa QQFieldElem
+   @test QQ(2, 3) + BigInt(2)//5 isa QQFieldElem
+   @test QQ(2, 3) - BigInt(2)//5 isa QQFieldElem
+   @test QQ(2, 3)*(BigInt(2)//5) isa QQFieldElem
+
+   @test 2//5 + QQ(2, 3) isa QQFieldElem
+   @test 2//5 - QQ(2, 3) isa QQFieldElem
+   @test (2//5)*QQ(2, 3) isa QQFieldElem
+   @test 12345678901234567890//5 + QQ(2, 3) isa QQFieldElem
+   @test 12345678901234567890//5 - QQ(2, 3) isa QQFieldElem
+   @test (12345678901234567890//5)*QQ(2, 3) isa QQFieldElem
+   @test BigInt(2)//5 + QQ(2, 3) isa QQFieldElem
+   @test BigInt(2)//5 - QQ(2, 3) isa QQFieldElem
+   @test (BigInt(2)//5)*QQ(2, 3) isa QQFieldElem
+
+   a = QQ(2, 3)
+
+   @test a !== a + 0
+   @test a !== a + BigInt(0)
+   @test a !== a + ZZ(0)
+   @test a !== a + QQ(0)
+   @test a !== a + 0//1
+   @test a !== a + BigInt(0)//1
+   @test a !== 0 + a
+   @test a !== BigInt(0) + a
+   @test a !== ZZ(0) + a
+   @test a !== QQ(0) + a
+   @test a !== 0//1 + a
+   @test a !== BigInt(0)//1 + a
+
+   @test a !== a - 0
+   @test a !== a - BigInt(0)
+   @test a !== a - ZZ(0)
+   @test a !== a - QQ(0)
+   @test a !== a - 0//1
+   @test a !== a - BigInt(0)//1
+   
+
+   @test a !== a*1
+   @test a !== a*BigInt(1)
+   @test a !== a*ZZ(1)
+   @test a !== a*QQ(1)
+   @test a !== a*(1//1)
+   @test a !== a*(BigInt(1)//1)
+   @test a !== 1*a
+   @test a !== BigInt(1)*a
+   @test a !== ZZ(1)*a
+   @test a !== QQ(1)*a
+   @test a !== (1//1)*a
+   @test a !== (BigInt(1)//1)*a
+end
+
+@testset "Rings.QQ.comparison" begin
+   @test QQ(2, 3) == QQ(2, 3)
+
+   @test QQ(2, 3) == 2//3
+   @test QQ(2, 3) == BigInt(2)//3
+
+   @test QQ(2) == 2
+   @test QQ(2) == BigInt(2)
+   @test QQ(2) == ZZ(2)
+
+   @test 2//3 == QQ(2, 3)
+   @test BigInt(2)//3 == QQ(2, 3)
+
+   @test 2 == QQ(2)
+   @test BigInt(2) == QQ(2)
+   @test ZZ(2) == QQ(2)
+
+   @test QQ(2, 3) > 0
+   @test QQ(2, 3) > BigInt(0)
+   @test QQ(2, 3) > 0//1
+   @test QQ(2, 3) > BigInt(0)//1
+   @test QQ(2, 3) > ZZ(0)
+   @test QQ(2, 3) > QQ(0)
+
+   @test QQ(2, 3) < 1
+   @test QQ(2, 3) < BigInt(1)
+   @test QQ(2, 3) < 1//1
+   @test QQ(2, 3) < BigInt(1)//1
+   @test QQ(2, 3) < ZZ(1)
+   @test QQ(2, 3) < QQ(1)
+end
+
+@testset "Rings.QQ.divexact" begin
+   @test divexact(QQ(2, 3), QQ(3, 2)) isa QQFieldElem
+   @test divexact(QQ(2, 3), 3//2) isa QQFieldElem
+   @test divexact(QQ(2, 3), BigInt(3)//2) isa QQFieldElem
+   @test divexact(2//3, QQ(2, 3)) isa QQFieldElem
+   @test divexact(BigInt(2)//3, QQ(2, 3)) isa QQFieldElem
+
+   @test divexact(QQ(2, 3), 2) isa QQFieldElem
+   @test divexact(QQ(2, 3), BigInt(2)) isa QQFieldElem
+   @test divexact(QQ(2, 3), ZZ(2)) isa QQFieldElem
+   @test divexact(2, QQ(2, 3)) isa QQFieldElem
+   @test divexact(BigInt(2), QQ(2, 3)) isa QQFieldElem
+   @test divexact(ZZ(2), QQ(2, 3)) isa QQFieldElem
+
+   @test divexact(QQ(2, 3), QQ(2, 3)) == 1
+   @test divexact(QQ(2, 3), 5) == 2//15
+   @test divexact(QQ(2, 3), ZZ(5)) == 2//15
+   @test divexact(5, QQ(2, 3)) == 15//2
+   @test divexact(ZZ(5), QQ(2, 3)) == 15//2
+
+   @test_throws DivideError divexact(QQ(2, 3), 0)
+   @test_throws DivideError divexact(QQ(2, 3), BigInt(0))
+   @test_throws DivideError divexact(QQ(2, 3), ZZ(0))
+   @test_throws DivideError divexact(QQ(2, 3), 0//1)
+   @test_throws DivideError divexact(QQ(2, 3), BigInt(0)//1)
+   @test_throws DivideError divexact(QQ(2, 3), QQ(0))
+end
+
+@testset "Rings.QQ.powering" begin
+   @test QQ(2, 3)^0 isa QQFieldElem
+   @test QQ(2, 3)^1 isa QQFieldElem
+   @test QQ(2, 3)^2 isa QQFieldElem
+   @test QQ(2, 3)^-1 isa QQFieldElem
+   @test QQ(2, 3)^-1 isa QQFieldElem
+
+   @test QQ(2, 3)^0 == 1
+   @test QQ(2, 3)^1 == 2//3
+   @test QQ(2, 3)^2 == 4//9
+   @test QQ(2, 3)^-1 == 3//2
+   @test QQ(2, 3)^-2 == 9//4
+
+   @test QQ(1)^0 == 1
+   @test QQ(1)^1 == 1
+   @test QQ(-1)^0 == 1
+   @test QQ(-1)^1 == -1
+   @test QQ(-1)^2 == 1
+   @test QQ(-1)^-1 == -1
+   @test QQ(-1)^-2 == 1
+   @test QQ(2)^3 == 8
+   @test QQ(2)^-3 == 1//8
+
+   @test QQ(0)^1 == 0
+   @test QQ(0)^0 == 1
+      
+   @test_throws DivideError QQ(0)^-1
+   @test_throws DivideError QQ(0)^-2
+end
