@@ -10,7 +10,7 @@
   @test elem_type(S) == QQPolyRingElem
   @test elem_type(QQPolyRing) == QQPolyRingElem
   @test parent_type(QQPolyRingElem) == QQPolyRing
-  @test dense_poly_type(QQFieldElem) == QQPolyRingElem
+  @test poly_type(QQFieldElem) == QQPolyRingElem
 
   @test isa(S, QQPolyRing)
 
@@ -648,5 +648,5 @@ end
   R, x = polynomial_ring(ZZ, "x")
   @test_throws ErrorException R(f)
   f = 7*y^2 + 3*y + 2
-  @test @inferred R(f) == 7*x^2 + 3*x + 2
+  @test 7*x^2 + 3*x + 2 == @inferred R(f)
 end
