@@ -242,7 +242,7 @@ end
   @test trailing_coefficient(3x^2*y^2 + 2x*y + 5x) == 5
   @test trailing_coefficient(x) == 1
   @test trailing_coefficient(S(2)) == 2
-  @test trailing_coefficient(S()) == 0
+  @test_throws ArgumentError trailing_coefficient(S())
 
   f = zero(S)
   @test setcoeff!(f, [1, 0], R(1)) == x
